==> thirdparty-service-biz-0.0.9.10-20180319.064614-2-sources.jar: cn/com/duiba/biz/phonebill/supplier/OufeiPhonebillSupplier.java <==
package cn.com.duiba.biz.phonebill.supplier;

import cn.com.duiba.domain.MessageUniqueCheckDO;
import cn.com.duiba.domain.SupplierRequest;
import cn.com.duiba.domain.SupplierResponse;
import cn.com.duiba.service.HttpAsyncClientPool;
import cn.com.duiba.service.MessageService;
import cn.com.duiba.tool.HttpRequestLog;
import cn.com.duiba.tool.JsonTool;
import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.concurrent.FutureCallback;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Class : 欧飞小额（电信10元以下）
 */
@Service
public class OufeiPhonebillSupplier {

	private static Logger log = LoggerFactory.getLogger(OufeiPhonebillSupplier.class);

	@Autowired
	private MessageService messageService;
	@Autowired
	private HttpAsyncClientPool httpAsyncClientPool;

	/**
	 * 提交到HTTP请求池
	 * @param message
	 * @param callbackTopic
	 * @param msgTag
	 * @param msgKey
	 */
	public void asyncSubmit(final SupplierRequest message, final String callbackTopic, final String msgTag, final String msgKey) {
		if(!messageService.messageUniqueCheck(message.getSupplierOrderId(), MessageUniqueCheckDO.TYPE_PHONEBILL)){
			return;
		}
		HttpPost post = new HttpPost(message.getHttpUrl());
		HttpRequestLog.logUrl("[action phonebill] [tag request] [bizId " + message.getOrderId() + "] [url " + message.getHttpUrl() + "]");
		httpAsyncClientPool.submit(message.getAppId(), post, new FutureCallback<HttpResponse>() {

			@Override
			public void completed(HttpResponse response) {
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setSupplierName(message.getSupplierName());
					resp.setUrl(message.getHttpUrl());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_COMPLETED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
					String body = EntityUtils.toString(response.getEntity());
					resp.setBody(body);
				} catch (Exception e) {
					log.error("OufeiPhonebillSupplier completed", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

			@Override
			public void failed(Exception ex) {
				log.error("OufeiPhonebillSupplier failed orderId:" + message.getOrderId(), ex);
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_FAILED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
					resp.setErrorMessage(ex.getClass().getName() + ":" + ex.getMessage());
				} catch (Exception e) {
					log.error("OufeiPhonebillSupplier completed", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

			@Override
			public void cancelled() {
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_CANCELLED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
				} catch (Exception e) {
					log.error("OufeiPhonebillSupplier cancelled", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

		});
	}
	
	private void finallyBlock(SupplierRequest message, SupplierResponse response, String callbackTopic, String msgTag, String msgKey) {
		try {
			response.setUrl(message.getHttpUrl());
			response.setSupplierName(message.getSupplierName());
			response.setSupplierOrderId(message.getSupplierOrderId());
			response.setOrderId(message.getOrderId());
			response.setAppId(message.getAppId());
			response.setConsumerId(message.getConsumerId());
			String body = JsonTool.objectToJson(response);
			HttpRequestLog.logUrl("[action phonebill] [tag response] [callback " + response.getCallbackType() + "] [bizId " + message.getOrderId() + "] [body " + response.getBody() + "]");
			messageService.sendMsg(callbackTopic, msgTag, msgKey, body);
		} catch (Exception e) {
			log.error("OufeiPhonebillSupplier callback:" + message.getOrderId(), e);
		}
	}

}

==> thirdparty-service-biz-1.0.33.p2-20211015.034711-1-sources.jar: cn/com/duiba/biz/phonebill/supplier/OufeiPhonebillSupplier.java <==
package cn.com.duiba.biz.phonebill.supplier;

import cn.com.duiba.domain.MessageUniqueCheckDO;
import cn.com.duiba.domain.SupplierRequest;
import cn.com.duiba.domain.SupplierResponse;
import cn.com.duiba.mq.RocketMQMsgProducer;
import cn.com.duiba.service.HttpAsyncClientPool;
import cn.com.duiba.service.MessageService;
import cn.com.duiba.tool.HttpRequestLog;
import cn.com.duiba.tool.JsonTool;
import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.concurrent.FutureCallback;
import org.apache.http.util.EntityUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * Class : 欧飞小额（电信10元以下）
 */
@Service
public class OufeiPhonebillSupplier {

	private static Logger log = LoggerFactory.getLogger(OufeiPhonebillSupplier.class);

	@Autowired
	private MessageService messageService;
	@Autowired
	private RocketMQMsgProducer rocketMQMsgProducer;
	@Autowired
	private HttpAsyncClientPool httpAsyncClientPool;

	/**
	 * 提交到HTTP请求池
	 * @param message
	 * @param callbackTopic
	 * @param msgTag
	 * @param msgKey
	 */
	public void asyncSubmit(final SupplierRequest message, final String callbackTopic, final String msgTag, final String msgKey) {
		if(!messageService.messageUniqueCheck(message.getSupplierOrderId(), MessageUniqueCheckDO.TYPE_PHONEBILL)){
			return;
		}
		HttpPost post = new HttpPost(message.getHttpUrl());
		HttpRequestLog.logUrl("[action phonebill] [tag request] [bizId " + message.getOrderId() + "] [url " + message.getHttpUrl() + "]");
		httpAsyncClientPool.submit(message.getAppId(), post, new FutureCallback<HttpResponse>() {

			@Override
			public void completed(HttpResponse response) {
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setSupplierName(message.getSupplierName());
					resp.setUrl(message.getHttpUrl());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_COMPLETED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
					String body = EntityUtils.toString(response.getEntity());
					resp.setBody(body);
				} catch (Exception e) {
					log.error("OufeiPhonebillSupplier completed", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

			@Override
			public void failed(Exception ex) {
				log.error("OufeiPhonebillSupplier failed orderId:" + message.getOrderId(), ex);
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_FAILED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
					resp.setErrorMessage(ex.getClass().getName() + ":" + ex.getMessage());
				} catch (Exception e) {
					log.error("OufeiPhonebillSupplier completed", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

			@Override
			public void cancelled() {
				SupplierResponse resp = new SupplierResponse();
				try {
					resp.setOrderId(message.getOrderId());
					resp.setSupplierOrderId(message.getSupplierOrderId());
					resp.setCallbackType(SupplierResponse.CALLBACK_TYPE_CANCELLED);
					resp.setAppId(message.getAppId());
					resp.setConsumerId(message.getConsumerId());
				} catch (Exception e) {
					log.error("OufeiPhonebillSupplier cancelled", e);
				} finally {
					finallyBlock(message, resp, callbackTopic, msgTag, msgKey);
				}
			}

		});
	}
	
	private void finallyBlock(SupplierRequest message, SupplierResponse response, String callbackTopic, String msgTag, String msgKey) {
		try {
			response.setUrl(message.getHttpUrl());
			response.setSupplierName(message.getSupplierName());
			response.setSupplierOrderId(message.getSupplierOrderId());
			response.setOrderId(message.getOrderId());
			response.setAppId(message.getAppId());
			response.setConsumerId(message.getConsumerId());
			String body = JsonTool.objectToJson(response);
			HttpRequestLog.logUrl("[action phonebill] [tag response] [callback " + response.getCallbackType() + "] [bizId " + message.getOrderId() + "] [body " + response.getBody() + "]");
			if(callbackTopic.contains("MQ")){
				rocketMQMsgProducer.sendMsg(callbackTopic, msgTag, msgKey, body,false,null);
			}else{
				messageService.sendMsg(callbackTopic,msgTag,msgKey,body);
			}
		} catch (Exception e) {
			log.error("OufeiPhonebillSupplier callback:" + message.getOrderId(), e);
		}
	}

}
